@@ -1,13 +1,13 @@
 bootstrap.copy = function ( www.directory, package.name ){
-	css_from = file.path( find.package(package.name), "bootstrap/css", fsep = "/" )
-	js_from = file.path( find.package(package.name), "bootstrap/js", fsep = "/" )
-	fonts_from = file.path( find.package(package.name), "bootstrap/fonts", fsep = "/" )
+	css_from = file.path( system.file(package = package.name), "bootstrap/css", fsep = "/" )
+	js_from = file.path( system.file(package = package.name), "bootstrap/js", fsep = "/" )
+	fonts_from = file.path( system.file(package = package.name), "bootstrap/fonts", fsep = "/" )
 
 	css_to = file.path( www.directory, "css", fsep = "/" )
 	js_to = file.path( www.directory, "js", fsep = "/" )
 	fonts_to = file.path( www.directory, "fonts", fsep = "/" )
-	
-	
+
+
 	if( !file.exists( css_to ) ){
 		file.copy( from = css_from, to = www.directory,  overwrite = T, recursive = T )
 	}
