@@ -9,6 +9,7 @@
 package org.lysis.reporters.docs;
 
 import java.io.File;
+
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.InputStream;
@@ -46,6 +47,7 @@ import org.lysis.reporters.docx4r.tools.BookmarkObject;
 import org.lysis.reporters.docx4r.tools.DocExplorer;
 import org.lysis.reporters.formats.ParProperties;
 import org.lysis.reporters.img.DrawingML;
+import org.lysis.reporters.img.Image;
 import org.lysis.reporters.lists.NumberingDefinition;
 import org.lysis.reporters.tables.FlexTable;
 import org.lysis.reporters.text.CodeBlock;
@@ -113,6 +115,10 @@ public class docx4R {
 	public WordprocessingMLPackage getBaseDocument(){
 		return basedoc;
 	}
+	public String getNextRelID(){
+		return "rId" + basedoc.getMainDocumentPart().relationships.size();
+	}
+	
 	public NumberingDefinitionsPart getNumberingDefinitionsPart(){
 		return ndp;
 	}
@@ -254,6 +260,7 @@ public class docx4R {
 		if( Debug.debug) System.err.println("getElementIndex:" + eltIndex);
 		return eltIndex;
 	}
+
 	
 	public void writeDocxToStream(String target) throws Exception{
 		if( sessionFactory.isOpen() ){
@@ -307,7 +314,9 @@ public class docx4R {
 			((ContentAccessor)p.getParent()).getContent().remove(p);
 		}
 	}
-	
+	public void deleteContent( ){
+		basedoc.getMainDocumentPart().getContent().clear();
+	}
 	public void deleteBookmarkNextContent( String bookmark ){
 		BookmarkObject bo = DocExplorer.getBookmarkObject(bookmark, basedoc);
 
@@ -336,7 +345,7 @@ public class docx4R {
 
 		basedoc.getMainDocumentPart().getContent().add(toc.get_docx_elt());
 
-		eltIndex = (int) toc.nextUniqueId();
+		eltIndex = (int) toc.next_id();
 		eventManage();
 	}
 	
@@ -348,7 +357,7 @@ public class docx4R {
 		Tbl tbl;
 		tbl = dt.get_docx_elt();
 		basedoc.getMainDocumentPart().addObject(tbl);
-		eltIndex = (int) dt.nextUniqueId();
+		eltIndex = (int) dt.next_id();
 		eventManage();
 	}
 	
@@ -366,7 +375,7 @@ public class docx4R {
 			Tbl tbl = dt.get_docx_elt();
 		    int i = ((ContentAccessor)p.getParent()).getContent().indexOf(p);
 		    ((ContentAccessor)p.getParent()).getContent().add(i+1, tbl);
-			eltIndex = (int) dt.nextUniqueId();
+			eltIndex = (int) dt.next_id();
 
 		} else throw new Exception("can't find bookmark '" + bookmark + "'." );
 
@@ -378,7 +387,7 @@ public class docx4R {
 		rscript.setParProperties(pp);
 		rscript.setUID(eltIndex + 1 );
 		basedoc.getMainDocumentPart().getContent().addAll(rscript.get_docx_elt());
-		eltIndex = (int) rscript.nextUniqueId();
+		eltIndex = (int) rscript.next_id();
 		eventManage();
 	}
 	
@@ -410,7 +419,7 @@ public class docx4R {
 		script.setParProperties(pp);
 		script.setUID(eltIndex + 1 );
 		basedoc.getMainDocumentPart().getContent().addAll(script.get_docx_elt());
-		eltIndex = (int) script.nextUniqueId();
+		eltIndex = (int) script.next_id();
 		eventManage();
 	}
 	
@@ -524,7 +533,7 @@ public class docx4R {
 		img.setParProperties(pp);
 		img.setUID(eltIndex+1);
 		basedoc.getMainDocumentPart().addObject(img.get_docx_elt());
-		eltIndex = (int) img.nextUniqueId();
+		eltIndex = (int) img.next_id();
 		eventManage();
 	}
 
@@ -542,11 +551,20 @@ public class docx4R {
 	    	img.set_docx_bookmark(bookmark, bo.getBookmarkID());
 	    	((ContentAccessor)p.getParent()).getContent().add(i, 
 	    			img.get_docx_elt());
-			eltIndex = (int) img.nextUniqueId();
+			eltIndex = (int) img.next_id();
 		} else System.err.println("can't find bookmark '" +bookmark+"'.");;
 
 	}
+	
 
+	public void add_png( String[] files, String[] names, double[] widths, double[] heights ) throws Exception {
+		for( int i = 0 ; i < files.length ; i++ ){
+			Image img = new Image(files[i], (float)widths[i], (float)heights[i]);
+			img.setDOCXMLPackage(basedoc);
+			img.add_img_to_docx(names[i]);
+		}		
+	}
+	
 	public void add ( DrawingML dml, ParProperties pp ) throws Exception {
 
 		dml.setDOCXMLPackage(basedoc);
@@ -577,7 +595,7 @@ public class docx4R {
 			dml.set_docx_bookmark(bookmark, bo.getBookmarkID());
 			
 	    	((ContentAccessor)p.getParent()).getContent().add(i, dml.get_docx_elt());
-			eltIndex = (int) dml.nextUniqueId();
+			eltIndex = (int) dml.next_id();
 
 		} else throw new Exception("can't find bookmark '" +bookmark+"'." );
 	}
@@ -640,6 +658,9 @@ public class docx4R {
 
         main.addObject(chunk);
         eltIndex++;
-}
+    }
+    
+
+    
 }
 
