@@ -1,3 +1,11 @@
+/*
+ * This file is part of ReporteRs
+ * Copyright (c) 2014, David Gohel All rights reserved.
+ * This program is licensed under the GNU GENERAL PUBLIC LICENSE V3.
+ * You may obtain a copy of the License at :
+ * http://www.gnu.org/licenses/gpl.html
+ */
+
 package org.lysis.reporters.tables;
 
 import java.util.LinkedHashMap;
@@ -22,6 +30,15 @@ public class MetaRows {
 		flexrowsList.put(nrows, fr);
 		nrows++;
 	}
+	public void insert(FlexRow fr) {
+		LinkedHashMap<Integer, FlexRow> newflexrowsList = new LinkedHashMap<Integer, FlexRow>();
+		newflexrowsList.put(0, fr);
+		for(int i = 0 ; i < nrows ; i++ ){
+			newflexrowsList.put(i+1, flexrowsList.get(i));
+		}
+		flexrowsList = newflexrowsList;
+		nrows++;
+	}
 	
 	public LinkedHashMap<Integer, FlexRow> get() {
 		return flexrowsList;
@@ -34,7 +51,7 @@ public class MetaRows {
 		flexrowsList.clear();
 		nrows=0;
 	}
-	
+
 	private void add(int i, int j, String par, TextProperties tp, boolean newPar) throws Exception{
 
 		if( nrows < 1) return;
@@ -43,6 +60,8 @@ public class MetaRows {
 		
 		FlexRow fr = flexrowsList.get(i);
 
+		if( !fr.hasCell(j) ) return;
+		
 		int col_id = fr.getCellIDCellAt(j);
 		if( Debug.debug ) System.err.println("col_id: " + col_id );
 
@@ -50,6 +69,8 @@ public class MetaRows {
 		if( Debug.debug ) System.err.println("set at:" + i + " col_id:" + col_id );
 
 		FlexCell fc = fr.getCell(col_id);
+//		System.out.println("colspan:" + fc.getColspan() + " pos:" + i + " - " +j + " - colid:" + col_id);
+		
 		if( newPar ) {
 			Paragraph p = new Paragraph();
 			p.addText(par, tp.getClone());
